# Pryngles

## PlanetaRY spaNGLES
![Animation](https://github.com/seap-udea/pryngles-public/blob/master/gallery/ecliptic-i_3.0e+01-lambobs_9.0e+01-betaobs_9.0e+01.gif?raw=true)

`Pryngles` is a `Python` package intended to produce useful
visualizations of the geometric configuration of a ringed exoplanet
(an exoplanet with a ring or exoring for short) and more importantly
to calculate the light-curve signatures produced by this kind of
planets.  The model behind the package has been developed in an effort
to predict the signatures that exorings may produce not only in the
light-curve of transiting exoplanets (a problem that has been
extensively studied) but also in the light of stars having
non-transiting exoplanets.

For the science behind the model please refer to the following papers:

> Zuluaga, Sucerquia & Alvarado, *The bright side of the light curve:
a general photometric model for non-transiting exorings*, in
preparation (2022).

> Sucerquia, Alvarado, Zuluaga, Montesinos, Bayo, *Scattered light may
  reveal the existence of ringed exoplanets*, Sucerquia, M.,
  Alvarado-Montes, J. A., Zuluaga, J. I., Montesinos, M., & Bayo,
  A. (2020). Scattered light may reveal the existence of ringed
  exoplanets. Monthly Notices of the Royal Astronomical Society:
  Letters, 496(1), L85-L90.

## Download

To download `pryngles` as a user:

```
   git clone https://github.com/seap-udea/pryngles.git
```

Or download the [`zip`
file](https://github.com/seap-udea/pryngles/archive/master.zip)

## Tutorial

A complete `Jupyter` tutorial is provided
[here](https://github.com/seap-udea/pryngles-public/blob/master/pryngles-tutorial.ipynb)

In this tutorial you will learn how to configure, install, use and even modify `pryngles`.

------------

This package has been designed and written originally by Jorge
I. Zuluaga, Mario Sucerquia & Jaime A. Alvarado-Montes (C) 2022
